/**
 * proto.h
 *
 * Serial radio clock protocol class definition.
 *
 * (c) 2008 John Sennesael
 * See the CHANGES file for license information.
 *
 */

#ifndef PROTO_H_INCLUDE
#define PROTO_H_INCLUDE

// global includes ============================================================

#include <string>

// class implementation =======================================================

/// Class to handle the radio clock's protocol 
/// and set the time.
class c_rclock_protocol
{

public: // ctor/dtor ----------------------------------------------------------

  // ctor
  c_rclock_protocol() : _delay(0),_dateprog("/bin/date"){}

public: // methods ------------------------------------------------------------

  /// Processes a line of text received from the serial device
  /// Will set the system time if DTM was received.
  /// \param line : line to process
  void ProcessLine(std::string line);

  /// Sets the delay to wait between time updates.
  /// \param delay : delay to wait between updates in seconds.
  void SetDelay(int delay){ _delay = delay; } 

  /// Sets the path to the date program.
  /// \param daterpog : path to the date program
  void SetDateProg(const std::string& dateprog){ _dateprog = dateprog; }

  /// Sets whether or not to be verbose when setting the time.
  /// \param verbose : Set to true to enable date set output.
  void SetVerbose(bool verbose){ _verbose = verbose; };

private: // private member variables ------------------------------------------

  /// Stores delay to wait between updates.
  int _delay;
  /// Stores path to the date program
  std::string _dateprog;
  /// Whether or not to print out the date we set.
  bool _verbose;

};

#endif
