/**
 * settings.cpp
 *
 * Class implementation for c_settings, a class
 * to hold for program settings.
 *
 * (c) 2008 John Sennesael
 *
 * This file is part of the rclockd program, which is licensed under the
 * GNU GPL license. Please see the LICENSE file distributed with this file
 * for details.
 *
 */

// global includes ============================================================

#include <iostream>
#include <fstream>
#include <vector>
#include <algorithm>
#include <boost/algorithm/string.hpp>

// local includes =============================================================

#include "settings.h"

// class implementation =======================================================

// constructor
c_settings::c_settings(const std::string& settings_file)
  : _settings_file(settings_file)
{
  // init members to sane defaults
  _device = "/dev/ttyS0";
  _delay = 5;
  _proto = new c_rclock_protocol();
}

// loads config file

int c_settings::Load()
{
  // open file
  std::ifstream file;
  file.open(_settings_file.c_str());
  if (file.is_open())
  {
    // start parsing    
    std::string line;
    int nline = 0;
    while(std::getline(file,line))
    {
      std::string key = "";
      std::string value = "";
      // strip newline characters
      boost::algorithm::replace_all(line,"\n","");
      // skip empty lines
      if (line == "") continue;
      // skip comments
      if (line[0] == '#') continue;
      // get key and value.
      size_t sep = line.find_first_of('=');
      if (sep != std::string::npos)
      {
        key = line.substr(0,line.find_first_of('='));
        value = line.substr(line.find_first_of('=')+1,line.length());
      }
      // trim leading/trailing spaces
      key.erase(0,key.find_first_not_of(" \t\n"));
      key.erase(key.find_last_not_of(" \t\n")+1);
      value.erase(0,value.find_first_not_of(" \t\n"));
      value.erase(value.find_last_not_of(" \t\n")+1);
      // key to lower case
      std::transform(key.begin(),key.end(),key.begin(),
                     static_cast<int(*)(int)>(std::tolower));
      // parse key
      if (key == "device")
      {
        _device = value;
      }
      else if (key == "delay")
      {
        _delay = atoi(value.c_str());
      }
      else if (key == "logfile")
      {
        _logfile = value;
      }
      else if (key == "date")
      {
        _dateprog = value;
      }
      else if (key == "logverbose")
      {
        if (value == "1")
          _logverbose = true;
        else
          _logverbose = false;
      }
      else
      {
        // unknown key
        file.close();
        return nline;
      }
      nline++;
    }
  }
  else
  {
    return -1;
  }
  file.close();
  return 0;
}


