/**
 * settings.h
 *
 * Class definition for c_settings, a class
 * to hold for program settings.
 *
 * (c) 2008 John Sennesael
 *
 * This file is part of the rclockd program, which is licensed under the
 * GNU GPL license. Please see the LICENSE file distributed with this file
 * for details.
 *
 */

#ifndef SETTINGS_H_INCLUDE
#define SETTINGS_H_INCLUDE

// global includes ============================================================

#include <string>

// local includes =============================================================

#include "proto.h"

// class definition ===========================================================

/// A class to manage program settings.
class c_settings
{

public: // construction/destruction -------------------------------------------

  /// constructor
  /// \param settings_file Optional settings file to read.
  c_settings(const std::string& settings_file="");

public: // Methods ------------------------------------------------------------

  /// Loads settings from config file.
  /// \return Returns 0 on success.
  /// \return Returns -1 if settings file could not be opened.
  /// \return Returns error line number if there was a config syntax problem.
  int Load();
  /// Returns device string setting (eg: /dev/ttyS0)
  const std::string& GetDevice() const { return _device; }
  /// Returns the delay between time updates.  
  long GetDelay() const { return _delay; }
  /// Returns the path to the log file.
  const std::string& GetLogFile() const { return _logfile; }
  /// Returns the path to the date program.
  const std::string& GetDateProg() const { return _dateprog; }
  /// Returns true if verbose logging is on.
  bool GetLogVerbose() const { return _logverbose; }
  /// Returns the proto object.
  c_rclock_protocol* GetProto() const { return _proto; } 
private: // private member variables ------------------------------------------

  /// Stores config file path.
  std::string _settings_file;
  /// Stores path to serial device. (eg: /dev/ttyS0)
  std::string _device;
  /// Stores path to the log file
  std::string _logfile;
  /// Stores path to the date program
  std::string _dateprog;
  /// Delay between time updates.
  long _delay;
  /// Stores verbose logging setting.
  bool _logverbose;
  /// Stores ptr to radio clock protocol object
  c_rclock_protocol* _proto; 
};

#endif


