/**
 * system.cpp
 *
 * Implemention for system class. - OO wrapper to daemonize the program.
 *
 * (c) 2008 John Sennesael
 *
 * This file is part of the rclockd program, which is licensed under the
 * GNU GPL license. Please see the LICENSE file distributed with this file
 * for details.    
 *
 */

// global includes ============================================================

#include <stdexcept>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <sys/resource.h>
#include <fcntl.h>
#include <iostream>
#include <fstream>
#include <ostream>

// local includes =============================================================

#include "system.h"

// class implementation =======================================================

// daemonize process.
void c_system::Daemonize()
{
  using namespace std;
  int errno;
  umask(0);
  rlimit rl;
  if (getrlimit(RLIMIT_NOFILE, &rl) < 0)
  {
    cerr << "Error: Could not get rlimit." << endl;
    cerr.flush();
    throw std::runtime_error(strerror(errno));
  }

  // fork
  pid_t pid;
  if ((pid = fork()) < 0)
  {
    cerr << "Error: Could not fork." << endl;
    cerr.flush();
    throw std::runtime_error(strerror(errno));
  } 
  else if (pid != 0) 
  {
    exit(0);
  }
  setsid();
  if (rl.rlim_max == RLIM_INFINITY)
    rl.rlim_max = 1024;
  
  _log = new ofstream(_settings->GetLogFile().c_str());
  _outbuffer = cout.rdbuf(_log->rdbuf());
  _logbuffer = clog.rdbuf(_log->rdbuf());
  _errbuffer = clog.rdbuf(_log->rdbuf());
  clog << "rclockd starting up." << endl;
}

