/**
 * system.h
 *
 * System class definition. OO wrapper for daemonizing the program.
 *
 * (c) 2008 John Sennesael
 *
 * This file is part of the rclockd program, which is licensed under the
 * GNU GPL license. Please see the LICENSE file distributed with this file
 * for details.    
 */

#ifndef SYSTEM_H_INCLUDE
#define SYSTEM_H_INCLUDE

// global includes ============================================================

#include <fstream>

// local includes =============================================================

#include "settings.h"

// class implementation =======================================================

/// Wrapper class to perform certain OS functions
class c_system
{

public: // ctor/dtor ----------------------------------------------------------

  /// constructor
  /// \param settings : pointer to the settings object.
  c_system(c_settings* settings) : _settings(settings),
                                   _log(NULL),
                                   _outbuffer(NULL),
                                   _errbuffer(NULL),
                                   _logbuffer(NULL) {}
                                   
public: // methods ------------------------------------------------------------

  /// Forks the program and runs in background.
  void Daemonize();

private: // private member variables ------------------------------------------

  /// Stores settings object pointer.
  c_settings* _settings;
  /// stores log file stream ptr.
  std::ofstream* _log;
  /// log buffer stream for cout.
  std::streambuf* _outbuffer;
  /// log buffer stream for cerr.
  std::streambuf* _errbuffer;
  /// log buffer stream for clog.
  std::streambuf* _logbuffer;
};

#endif
